embassy-usb

Crates

git

Versions

default

Flavors

Speaker

Struct Speaker 

pub struct Speaker<'d, D: Driver<'d>> {
    pub stream: Stream<'d, D>,
    pub feedback: Feedback<'d, D>,
    pub control_monitor: ControlMonitor<'d>,
}
Implementation of the USB audio class 1.0.

Fields

stream: Stream<'d, D>

Stream

feedback: Feedback<'d, D>

Feedback

control_monitor: ControlMonitor<'d>

Control Monitor

Implementations

Source

impl<'d, D: Driver<'d>> Speaker<'d, D>

pub fn new( builder: &mut Builder<'d, D>, state: &'d mut State<'d>, max_packet_size: u16, resolution: SampleWidth, sample_rates_hz: &[u32], channels: &'d [Channel], feedback_refresh_period: FeedbackRefresh, ) -> Self

Creates a new Speaker device, split into a stream, feedback, and a control change notifier.

The packet size should be chosen, based on the expected transfer size of samples per (micro)frame. For example, a stereo stream at 32 bit resolution and 48 kHz sample rate yields packets of 384 byte for full-speed USB (1 ms frame interval) or 48 byte for high-speed USB (125 us microframe interval). When using feedback, the packet size varies and thus, the max_packet_size should be increased (e.g. to double).

Arguments
  • builder - The builder for the class.
  • state - The internal state of the class.
  • max_packet_size - The maximum packet size per (micro)frame.
  • resolution - The audio sample resolution.
  • sample_rates_hz - The supported sample rates in Hz.
  • channels - The advertised audio channels (up to 12). Entries must be unique, or this function panics.
  • feedback_refresh_period - The refresh period for the feedback value.